diff --git a/front-end/public/index.html b/front-end/public/index.html
index aa069f2..5fd579a 100644
--- a/front-end/public/index.html
+++ b/front-end/public/index.html
@@ -9,7 +9,7 @@
name="description"
content="Web site created using create-react-app"
/>
-
+
-
React App
+ Bill Balancer
diff --git a/front-end/public/logo.png b/front-end/public/logo.png
new file mode 100644
index 0000000..9ddc130
Binary files /dev/null and b/front-end/public/logo.png differ
diff --git a/front-end/src/App.js b/front-end/src/App.js
index 814432d..6d84b42 100644
--- a/front-end/src/App.js
+++ b/front-end/src/App.js
@@ -122,12 +122,13 @@ function App() {
// dark mode should not affect Login and ForgotPassword page
function AppContainer({ isDarkMode, children }) {
const location = useLocation();
// check if the current route is either the login page or the forgot password page
const isLoginPage = location.pathname === "/";
const isForgotPasswordPage = location.pathname === "/forgot-password";
- // disable dark mode on Login and ForgotPassword page
+ const isSignupPage = location.pathname === "/signup";
+ // disable dark mode on Login, ForgotPassword, and Signup page
const containerClass =
- isDarkMode && !isLoginPage && !isForgotPasswordPage
+ isDarkMode && !isLoginPage && !isForgotPasswordPage && !isSignupPage
? "container dark-mode"
: "container";
return
@@ -122,12 +122,13 @@ function App() {
function AppContainer({ isDarkMode, children }) {
const location = useLocation();
- // check if the current route is either the login page or the forgot password page
+ // check if the current route is the login page, the forgot password page, or the signup page
const isLoginPage = location.pathname === "/";
const isForgotPasswordPage = location.pathname === "/forgot-password";